@@ -224,6 +224,18 @@ def get_parser():
                              'allowed ips and denied ips options will still affect the filter as well as the default '
                              'set frameworks. If no framework filtering is needed the built in default frameworks can '
                              'be overriden by calling the "-f" option with "" as an argument.')
+    parser.add_argument('--disable-spinner',
+                        '-ds',
+                        action='store_true',
+                        default=environment_variable_boolean(os.environ.get('AWS_LABELER_DISABLE_SPINNER',
+                                                                            False)),
+                        help='If set spinner will be disabled on the CLI.')
+    parser.add_argument('--disable-banner',
+                        '-db',
+                        action='store_true',
+                        default=environment_variable_boolean(os.environ.get('AWS_LABELER_DISABLE_BANNER',
+                                                                            False)),
+                        help='If set banner will be disabled on the CLI.')
     parser.add_argument('--validate-metadata-file',
                         '-vm',
                         action=OverridingArgument,
@@ -270,7 +282,7 @@ def validate_metadata_file(file_path, parser):
 
     """
     try:
-        with open(file_path, 'r') as ifile:
+        with open(file_path, 'r', encoding='utf-8') as ifile:
             LOGGER.debug(f'Received local file "{file_path}" to validate.')
             contents = ifile.read()
             data = json.loads(contents)
@@ -299,13 +311,13 @@ def get_arguments(arguments=None):  # noqa: MC0001
     if args.validate_metadata_file:
         # if overriding argument is set then we do not check any other arguments and we exit straight
         # after validating the argument
-        raise validate_metadata_file(args.validate_metadata_file, parser)
+        validate_metadata_file(args.validate_metadata_file, parser)
     # Since mutual exclusive cannot work with environment variables we need to check explicitly for all pairs of
     # mutual relations that are not allowed.
     if all([args.allowed_account_ids, args.denied_account_ids]):
-        raise parser.error('argument --allowed-account-ids/-a: not allowed with argument --denied-account-ids/-d')
+        parser.error('argument --allowed-account-ids/-a: not allowed with argument --denied-account-ids/-d')
     if all([args.allowed_regions, args.denied_regions]):
-        raise parser.error('argument --allowed-regions/-ar: not allowed with argument --denied-regions/-dr')
+        parser.error('argument --allowed-regions/-ar: not allowed with argument --denied-regions/-dr')
     export_metrics_set = environment_variable_boolean(os.environ.get('AWS_LABELER_EXPORT_ONLY_METRICS'))
     if export_metrics_set:
         args.export_all = False
@@ -313,35 +325,35 @@ def get_arguments(arguments=None):  # noqa: MC0001
     try:
         _ = get_mutually_exclusive_args(*exclusive_args, required=True)
     except MissingRequiredArguments:
-        raise parser.error('one of the arguments --organizations-zone-name/-o --audit-zone-name/-z '
-                           '--single-account-id/-s is required')
+        parser.error('one of the arguments --organizations-zone-name/-o --audit-zone-name/-z '
+                     '--single-account-id/-s is required')
     except MutuallyExclusiveArguments:
-        raise parser.error('arguments --organizations-zone-name/-o --audit-zone-name/-z '
-                           '--single-account-id/-s are mutually exclusive')
+        parser.error('arguments --organizations-zone-name/-o --audit-zone-name/-z '
+                     '--single-account-id/-s are mutually exclusive')
     exclusive_args = [args.allowed_account_ids, args.denied_account_ids, args.single_account_id]
     try:
         _ = get_mutually_exclusive_args(*exclusive_args)
     except MutuallyExclusiveArguments:
-        raise parser.error('arguments --allowed-account-ids/-a --denied-account-ids/-d --single-account-id/-s are '
-                           'mutually exclusive')
+        parser.error('arguments --allowed-account-ids/-a --denied-account-ids/-d --single-account-id/-s are '
+                     'mutually exclusive')
     try:
         SecurityHub.validate_frameworks(args.frameworks)
     except InvalidFrameworks:
-        raise parser.error(f'{args.frameworks} are not valid supported security hub frameworks. Currently supported '
-                           f'are {SecurityHub.frameworks}')
+        parser.error(f'{args.frameworks} are not valid supported security hub frameworks. Currently supported '
+                     f'are {SecurityHub.frameworks}')
     for argument in ['allowed_account_ids', 'denied_account_ids']:
         try:
             _ = validate_account_ids(getattr(args, argument))
         except InvalidAccountListProvided:
-            raise parser.error(f'{getattr(args, argument)} contains invalid account ids.')
+            parser.error(f'{getattr(args, argument)} contains invalid account ids.')
     for argument in ['allowed_regions', 'denied_regions']:
         try:
             _ = validate_regions(getattr(args, argument))
         except InvalidRegionListProvided:
-            raise parser.error(f'{getattr(args, argument)} contains invalid regions.')
+            parser.error(f'{getattr(args, argument)} contains invalid regions.')
     if args.export_path and not DestinationPath(args.export_path).is_valid():
-        raise parser.error(f'{args.export_path} is an invalid export location. Example --export-path '
-                           f'/a/directory or --export-path s3://mybucket location')
+        parser.error(f'{args.export_path} is an invalid export location. Example --export-path '
+                     f'/a/directory or --export-path s3://mybucket location')
     return args
 
 
@@ -357,20 +369,20 @@ def setup_logging(level, config_file=None):
     # If there's no config file, logging will default to stdout.
     if config_file:
         try:
-            with open(config_file) as conf_file:
+            with open(config_file, encoding='utf-8') as conf_file:
                 configuration = json.loads(conf_file.read())
                 logging.config.dictConfig(configuration)
         except ValueError:
             print(f'File "{config_file}" is not valid json, cannot continue.')
-            raise SystemExit(1)
+            raise SystemExit(1) from None
         except FileNotFoundError:
             print(f'File "{config_file}" does not exist or cannot be read, cannot continue.')
-            raise SystemExit(1)
+            raise SystemExit(1) from None
     else:
         coloredlogs.install(level=level.upper())
 
 
-def wait_for_findings(method_name, method_argument, log_level, finding_type=None):
+def wait_for_findings(method_name, method_argument, log_level, finding_type=None, disable_spinner=False):
     """If log level is not debug shows a spinner while the callable provided gets security hub findings.
 
     Args:
@@ -378,13 +390,14 @@ def wait_for_findings(method_name, method_argument, log_level, finding_type=None
         method_argument: The argument to pass to the method.
         log_level: The log level as set by the user.
         finding_type: The type of the finding to use for the helping message.
+        disable_spinner: The spinner will be disabled while retrieving the findings.
 
     Returns:
         findings: A list of security hub findings as retrieved by the callable.
 
     """
     try:
-        if log_level != 'debug':
+        if all([log_level != 'debug', not disable_spinner]):
             with yaspin(text=f"Please wait while retrieving Security Hub{f' {finding_type} ' if finding_type else ' '}"
                              f"findings...", color="yellow") as spinner:
                 findings = method_name(method_argument) if method_argument else method_name()
@@ -393,7 +406,7 @@ def wait_for_findings(method_name, method_argument, log_level, finding_type=None
             findings = method_name(method_argument) if method_argument else method_name()
     except Exception as msg:
         LOGGER.error(msg)
-        raise SystemExit(1)
+        raise SystemExit(1) from None
     return findings
 
 
@@ -413,7 +426,8 @@ def get_zone_reporting_data(zone_name,
                             security_hub_query_filter,
                             log_level,
                             zone_type,
-                            metadata):
+                            metadata,
+                            disable_spinner):
     """Gets the reporting data for an organizations zone.
 
     Args:
@@ -432,6 +446,7 @@ def get_zone_reporting_data(zone_name,
         log_level: The log level set.
         zone_type: The type of zone to label.
         metadata: The metadata of the execution, provided to be enriched by the active ones.
+        disable_spinner: The spinner will be disabled while retrieving the findings.
 
     Returns:
         report_data, exporter_arguments
@@ -448,7 +463,7 @@ def get_zone_reporting_data(zone_name,
                             allowed_regions=allowed_regions,
                             denied_regions=denied_regions,
                             zone_type=zone_type)
-    wait_for_findings(EnergyLabeler.security_hub_findings.fget, labeler, log_level)
+    wait_for_findings(EnergyLabeler.security_hub_findings.fget, labeler, log_level, disable_spinner=disable_spinner)
     report_data = [['Zone:', labeler.zone.name],
                    ['Zone Security Score:', labeler.zone_energy_label.label],
                    ['Zone Percentage Coverage:', labeler.zone_energy_label.coverage],
@@ -466,7 +481,8 @@ def get_zone_reporting_data(zone_name,
         # resolved_findings = wait_for_findings(labeler.security_hub.get_findings,
         #                                       query_filter,
         #                                       log_level,
-        #                                       'resolved')
+        #                                       'resolved',
+        #                                       disable_spinner=disable_spinner)
         # report_data.append([f'Resolved Findings Last {report_closed_findings_days} Days:', len(resolved_findings)])
     if report_suppressed_findings:
         query_filter = labeler.security_hub.calculate_query_filter(SUPPRESSED_FINDINGS_QUERY,
@@ -476,7 +492,8 @@ def get_zone_reporting_data(zone_name,
         suppressed_findings = wait_for_findings(labeler.security_hub.get_findings,
                                                 query_filter,
                                                 log_level,
-                                                'suppressed')
+                                                'suppressed',
+                                                disable_spinner=disable_spinner)
         metadata.add_entry(MetadataEntry(title='Suppressed Findings:',
                                          value=str(len(suppressed_findings)),
                                          is_report_entry=True))
@@ -505,7 +522,8 @@ def get_account_reporting_data(account_id,
                                account_thresholds,
                                security_hub_query_filter,
                                log_level,
-                               metadata):
+                               metadata,
+                               disable_spinner):
     """Gets the reporting data for a single account.
 
     Args:
@@ -521,6 +539,7 @@ def get_account_reporting_data(account_id,
         security_hub_query_filter: The security hub filter to apply.
         log_level: The log level set.
         metadata: The metadata of the execution, provided to be enriched by the active ones.
+        disable_spinner: The spinner will be disabled while retrieving the findings.
 
     Returns:
         report_data, exporter_arguments
@@ -534,7 +553,8 @@ def get_account_reporting_data(account_id,
                                                       allowed_account_ids=[account_id],
                                                       denied_account_ids=None,
                                                       frameworks=frameworks)
-    unfiltered_findings = wait_for_findings(security_hub.get_findings, query_filter, log_level)
+    unfiltered_findings = wait_for_findings(security_hub.get_findings, query_filter, log_level,
+                                            disable_spinner=disable_spinner)
     security_hub_findings = security_hub.filter_findings_by_frameworks(unfiltered_findings, frameworks)
     account.calculate_energy_label(security_hub_findings)
     report_data = [['Account ID:', account.id],
@@ -555,14 +575,16 @@ def get_account_reporting_data(account_id,
         # resolved_findings = wait_for_findings(security_hub.get_findings,
         #                                       query_filter,
         #                                       log_level,
-        #                                       'resolved')
+        #                                       'resolved',
+        #                                       disable_spinner=disable_spinner)
         # report_data.append([f'Resolved Findings Last {report_closed_findings_days} Days:', len(resolved_findings)])
     if report_suppressed_findings:
         query_filter = SecurityHub.calculate_query_filter(SUPPRESSED_FINDINGS_QUERY,
                                                           allowed_account_ids=[account_id],
                                                           denied_account_ids=None,
                                                           frameworks=frameworks)
-        suppressed_findings = wait_for_findings(security_hub.get_findings, query_filter, log_level, 'suppressed')
+        suppressed_findings = wait_for_findings(security_hub.get_findings, query_filter, log_level, 'suppressed',
+                                                disable_spinner=disable_spinner)
         metadata.add_entry(MetadataEntry(title='Suppressed Findings:',
                                          value=str(len(suppressed_findings)),
                                          is_report_entry=True))
